==> igloo_0_1_2.tar.tgz: igloo_0_1_2/igloo/language/1/barnraiser_01/arrays/arr_man.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of Igloo
//
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------
// Tom Calthrop - 20th April 2004 (tom@barnraiser.org)

// name of the manual page / description for user
$lang['man'][0] = 			array('introduction', 'Introducing your guide');
$lang['man'][1] = 			array('account', 'Account Guide');
$lang['man'][2] = 			array('comment', 'Commenting Guide');
$lang['man'][3] = 			array('tag', 'Tagging Guide');
$lang['man'][4] = 			array('wiki_formatting', 'Formatting Guide');
$lang['man'][5] = 			array('file', 'Files Guide');
$lang['man'][6] = 			array('wiki', 'Wiki Guide');
$lang['man'][7] = 			array('blog', 'Blog Guide');
$lang['man'][8] = 			array('schedule', 'Events and tasks Guide');
$lang['man'][9] = 			array('forum', 'Discussion area Guide');
$lang['man'][10] = 			array('rss', 'RSS Guide');
$lang['man'][11] = 			array('newsletter', 'Newsletter Guide');
$lang['man'][12] = 			array('acs', 'Access control system');
$lang['man'][13] = 			array('calendar', 'Calendar');
$lang['man'][14] = 			array('customise', 'Customising Igloo');
$lang['man'][15] = 			array('faq', 'Frequently asked questions');
$lang['man'][16] = 			array('barnraiser', 'Who made Igloo?');

?>

==> igloo_0_1_7.tar.tgz: igloo_0_1_7/igloo/language/1/barnraiser_01/arrays/arr_man.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of Igloo
//
// Copyright (C) 2003, 2006 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------
// Tom Calthrop - 20th April 2004 (tom@barnraiser.org)

// name of the manual page / description for user
$lang['man'][0] = 			array('introduction', 'Introducing your guide');
$lang['man'][1] = 			array('account', 'Account Guide');
$lang['man'][2] = 			array('comment', 'Commenting Guide');
$lang['man'][3] = 			array('tag', 'Tagging Guide');
$lang['man'][4] = 			array('wiki_formatting', 'Formatting Guide');
$lang['man'][5] = 			array('file', 'Files Guide');
$lang['man'][6] = 			array('wiki', 'Wiki Guide');
$lang['man'][7] = 			array('blog', 'Blog Guide');
$lang['man'][8] = 			array('schedule', 'Events and tasks Guide');
$lang['man'][9] = 			array('forum', 'Discussion area Guide');
$lang['man'][10] = 			array('sn', 'Social networking Guide');
$lang['man'][20] = 			array('rss', 'RSS Guide');
$lang['man'][21] = 			array('newsletter', 'Newsletter Guide');
$lang['man'][22] = 			array('acs', 'Access control system');
$lang['man'][23] = 			array('calendar', 'Calendar');
$lang['man'][24] = 			array('customise', 'Customising Igloo');
$lang['man'][25] = 			array('faq', 'Frequently asked questions');
$lang['man'][26] = 			array('barnraiser', 'Who made Igloo?');

?>
